#
# @file    TestWriteMathML.py
# @brief   Write MathML unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/math/test/TestWriteMathML.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def util_NaN():
  z = 1e300
  z = z * z

  return z - z

def util_PosInf():
  z = 1e300
  z = z * z

  return z

def util_NegInf():
  z = 1e300
  z = z * z

  return -z 

def wrapString(s):
  return s
  pass

def MATHML_FOOTER():
  return "</math>"
  pass

def MATHML_HEADER():
  return "<math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n"
  pass

def MATHML_HEADER_UNITS():
  return "<math xmlns=\"http://www.w3.org/1998/Math/MathML\""
  pass

def MATHML_HEADER_UNITS2():
  return " xmlns:sbml=\"http://www.sbml.org/sbml/level3/version2/core\">\n"
  pass

def XML_HEADER():
  return "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
  pass

def wrapMathML(s):
  r = XML_HEADER()
  r += MATHML_HEADER()
  r += s
  r += MATHML_FOOTER()
  return r
  pass

def wrapMathMLUnits(s):
  r = XML_HEADER()
  r += MATHML_HEADER_UNITS()
  r += MATHML_HEADER_UNITS2()
  r += s
  r += MATHML_FOOTER()
  return r
  pass


class TestWriteMathML(unittest.TestCase):

  global S
  S = None
  global N
  N = None

  def equals(self, *x):
    if len(x) == 2:
      return x[0] == x[1]
    elif len(x) == 1:
      return x[0] == self.OSS.str()

  def setUp(self):
    self.N = None
    self.S = None
    pass  

  def tearDown(self):
    self.N = None
    self.S = None
    pass  

  def test_MathMLFormatter_ci(self):
    expected = wrapMathML("  <ci> foo </ci>\n")
    self.N = libsbml.parseFormula("foo")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_1(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> 0 <sep/> 3 </cn>\n"  
    )
    self.N = libsbml.parseFormula("0e3")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_2(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> 2 <sep/> 3 </cn>\n"  
    )
    self.N = libsbml.parseFormula("2e3")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_3(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> 1234567.8 <sep/> 3 </cn>\n"  
    )
    self.N = libsbml.parseFormula("1234567.8e3")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_4(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> 6.0221367 <sep/> 23 </cn>\n"  
    )
    self.N = libsbml.parseFormula("6.0221367e+23")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_5(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> 4 <sep/> -6 </cn>\n"  
    )
    self.N = libsbml.parseFormula(".000004")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_6(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> 4 <sep/> -12 </cn>\n"  
    )
    self.N = libsbml.parseFormula(".000004e-6")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_e_notation_7(self):
    expected = wrapMathML("  <cn type=\"e-notation\"> -1 <sep/> -6 </cn>\n"  
    )
    self.N = libsbml.parseFormula("-1e-6")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_integer(self):
    expected = wrapMathML("  <cn type=\"integer\"> 5 </cn>\n")
    self.N = libsbml.parseFormula("5")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_rational(self):
    expected = wrapMathML("  <cn type=\"rational\"> 1 <sep/> 3 </cn>\n"  
    )
    self.N = libsbml.ASTNode()
    self.N.setValue(1,3)
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_real_1(self):
    expected = wrapMathML("  <cn> 1.2 </cn>\n")
    self.N = libsbml.parseFormula("1.2")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_real_2(self):
    expected = wrapMathML("  <cn> 1234567.8 </cn>\n")
    self.N = libsbml.parseFormula("1234567.8")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_real_3(self):
    expected = wrapMathML("  <cn> -3.14 </cn>\n")
    self.N = libsbml.parseFormula("-3.14")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_real_locale(self):
    expected = wrapMathML("  <cn> 2.72 </cn>\n")
    self.N = libsbml.parseFormula("2.72")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_cn_units(self):
    expected = wrapMathMLUnits("  <cn sbml:units=\"mole\"> 1.2 </cn>\n")
    self.N = libsbml.parseFormula("1.2")
    self.N.setUnits("mole")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_constant_exponentiale(self):
    expected = wrapMathML("  <exponentiale/>\n")
    self.N = libsbml.ASTNode(libsbml.AST_CONSTANT_E)
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_constant_false(self):
    expected = wrapMathML("  <false/>\n")
    self.N = libsbml.ASTNode(libsbml.AST_CONSTANT_FALSE)
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_constant_infinity(self):
    expected = wrapMathML("  <infinity/>\n")
    self.N = libsbml.ASTNode()
    self.N.setValue( util_PosInf() )
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_constant_infinity_neg(self):
    #expected = wrapMathML("  <apply>\n" + 
    #"    <minus/>\n" + 
    #"    <infinity/>\n" + 
    #"  </apply>\n")
    #self.N = libsbml.ASTNode()
    #self.N.setValue(- util_PosInf())
    #self.S = libsbml.writeMathMLToString(self.N)
    #self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_constant_notanumber(self):
    expected = wrapMathML("  <notanumber/>\n")
    self.N = libsbml.ASTNode(libsbml.AST_REAL)
    self.N.setValue( util_NaN() )
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_constant_true(self):
    expected = wrapMathML("  <true/>\n")
    self.N = libsbml.ASTNode(libsbml.AST_CONSTANT_TRUE)
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_csymbol_avogadro(self):
    expected = wrapMathML("  <csymbol encoding=\"text\" " + "definitionURL=\"http://www.sbml.org/sbml/symbols/avogadro\"> NA </csymbol>\n")
    self.N = libsbml.ASTNode(libsbml.AST_NAME_AVOGADRO)
    self.N.setName("NA")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_csymbol_delay(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <csymbol encoding=\"text\" definitionURL=\"http://www.sbml.org/sbml/" + 
    "symbols/delay\"> my_delay </csymbol>\n" + 
    "    <ci> x </ci>\n" + 
    "    <cn> 0.1 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("delay(x, 0.1)")
    self.N.setName("my_delay")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_csymbol_time(self):
    expected = wrapMathML("  <csymbol encoding=\"text\" " + "definitionURL=\"http://www.sbml.org/sbml/symbols/time\"> t </csymbol>\n")
    self.N = libsbml.ASTNode(libsbml.AST_NAME_TIME)
    self.N.setName("t")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_function_1(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <ci> foo </ci>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "    <cn type=\"integer\"> 3 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("foo(1, 2, 3)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_function_2(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <ci> foo </ci>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "    <apply>\n" + 
    "      <ci> bar </ci>\n" + 
    "      <ci> z </ci>\n" + 
    "    </apply>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("foo(1, 2, bar(z))")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_lambda(self):
    expected = wrapMathML("  <lambda>\n" + 
    "    <bvar>\n" + 
    "      <ci> x </ci>\n" + 
    "    </bvar>\n" + 
    "    <bvar>\n" + 
    "      <ci> y </ci>\n" + 
    "    </bvar>\n" + 
    "    <apply>\n" + 
    "      <root/>\n" + 
    "      <degree>\n" + 
    "        <cn type=\"integer\"> 2 </cn>\n" + 
    "      </degree>\n" + 
    "      <apply>\n" + 
    "        <plus/>\n" + 
    "        <apply>\n" + 
    "          <power/>\n" + 
    "          <ci> x </ci>\n" + 
    "          <cn type=\"integer\"> 2 </cn>\n" + 
    "        </apply>\n" + 
    "        <apply>\n" + 
    "          <power/>\n" + 
    "          <ci> y </ci>\n" + 
    "          <cn type=\"integer\"> 2 </cn>\n" + 
    "        </apply>\n" + 
    "      </apply>\n" + 
    "    </apply>\n" + 
    "  </lambda>\n")
    self.N = libsbml.parseFormula("lambda(x, y, root(2, x^2 + y^2))")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_lambda_no_bvars(self):
    expected = wrapMathML("  <lambda>\n" + 
    "    <apply>\n" + 
    "      <plus/>\n" + 
    "      <cn type=\"integer\"> 2 </cn>\n" + 
    "      <cn type=\"integer\"> 2 </cn>\n" + 
    "    </apply>\n" + 
    "  </lambda>\n")
    self.N = libsbml.parseFormula("lambda(2 + 2)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_log(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <log/>\n" + 
    "    <logbase>\n" + 
    "      <cn type=\"integer\"> 2 </cn>\n" + 
    "    </logbase>\n" + 
    "    <ci> N </ci>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("log(2, N)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_minus(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <minus/>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("1 - 2")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_minus_unary_1(self):
    expected = wrapMathML("  <cn type=\"integer\"> -2 </cn>\n"  
    )
    self.N = libsbml.parseFormula("-2")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_minus_unary_2(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <minus/>\n" + 
    "    <ci> a </ci>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("-a")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_piecewise(self):
    expected = wrapMathML("  <piecewise>\n" + 
    "    <piece>\n" + 
    "      <apply>\n" + 
    "        <minus/>\n" + 
    "        <ci> x </ci>\n" + 
    "      </apply>\n" + 
    "      <apply>\n" + 
    "        <lt/>\n" + 
    "        <ci> x </ci>\n" + 
    "        <cn type=\"integer\"> 0 </cn>\n" + 
    "      </apply>\n" + 
    "    </piece>\n" + 
    "    <piece>\n" + 
    "      <cn type=\"integer\"> 0 </cn>\n" + 
    "      <apply>\n" + 
    "        <eq/>\n" + 
    "        <ci> x </ci>\n"  + 
    "        <cn type=\"integer\"> 0 </cn>\n" + 
    "      </apply>\n" + 
    "    </piece>\n" + 
    "    <piece>\n" + 
    "      <ci> x </ci>\n" + 
    "      <apply>\n" + 
    "        <gt/>\n" + 
    "        <ci> x </ci>\n"  + 
    "        <cn type=\"integer\"> 0 </cn>\n" + 
    "      </apply>\n" + 
    "    </piece>\n" + 
    "  </piecewise>\n")
    f =  "piecewise(-x, lt(x, 0), 0, eq(x, 0), x, gt(x, 0))";
    self.N = libsbml.parseFormula(f)
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_piecewise_otherwise(self):
    expected = wrapMathML("  <piecewise>\n" + 
    "    <piece>\n" + 
    "      <cn type=\"integer\"> 0 </cn>\n" + 
    "      <apply>\n" + 
    "        <lt/>\n" + 
    "        <ci> x </ci>\n" + 
    "        <cn type=\"integer\"> 0 </cn>\n" + 
    "      </apply>\n" + 
    "    </piece>\n" + 
    "    <otherwise>\n" + 
    "      <ci> x </ci>\n"  + 
    "    </otherwise>\n" + 
    "  </piecewise>\n")
    self.N = libsbml.parseFormula("piecewise(0, lt(x, 0), x)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_plus_binary(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <plus/>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("1 + 2")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_plus_nary_1(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <plus/>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "    <cn type=\"integer\"> 3 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("1 + 2 + 3")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_plus_nary_2(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <plus/>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "    <cn type=\"integer\"> 3 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("(1 + 2) + 3")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_plus_nary_3(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <plus/>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "    <cn type=\"integer\"> 3 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("1 + (2 + 3)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_plus_nary_4(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <plus/>\n" + 
    "    <cn type=\"integer\"> 1 </cn>\n" + 
    "    <cn type=\"integer\"> 2 </cn>\n" + 
    "    <apply>\n" + 
    "      <times/>\n" + 
    "      <ci> x </ci>\n" + 
    "      <ci> y </ci>\n" + 
    "      <ci> z </ci>\n" + 
    "    </apply>\n" + 
    "    <cn type=\"integer\"> 3 </cn>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("1 + 2 + x * y * z + 3")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_root(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <root/>\n" + 
    "    <degree>\n" + 
    "      <cn type=\"integer\"> 3 </cn>\n" + 
    "    </degree>\n" + 
    "    <ci> x </ci>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("root(3, x)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_MathMLFormatter_sin(self):
    expected = wrapMathML("  <apply>\n" + 
    "    <sin/>\n" + 
    "    <ci> x </ci>\n" + 
    "  </apply>\n")
    self.N = libsbml.parseFormula("sin(x)")
    self.S = libsbml.writeMathMLToString(self.N)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestWriteMathML))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python

import re
import sys

def getFunctionNames(filename):
    file = open(filename, 'r')
    functions = []

    for line in file.readlines():
        if re.search(r'\Adef ', line):
            functions.append(line[4:line.rfind('(')])

    file.close()
    return functions


def main (args):
    """Usage:
        pythondocpreprocessor.py sourcelibsbml.py outputlibsbml.py FILE FILE ...

    Each FILE is assumed to have the same name as a class (minus the .py
    file extension).  For each FILE, this program first removes the class
    definition from sourcelibsbml.py, appends the contents of FILE, and
    writes the result to outputlibsbml.py.  If FILE is empty, this has the
    effect of removing a class completely.  If FILE is a name that has
    equivalent in sourcelibsbml.py, the result is to add new content.

    Special case: the file libsbml.py is examined for function definitions
    to remove from the top level; it is not used as a class named 'libsbml'.
    """

    if len(sys.argv) < 4:
        print(main.__doc__)
        sys.exit(1)

    input     = open(args[1], 'r')
    output    = open(args[2], 'w')
    filenames = args[3:]

    contents  = ""

    # Remove classes and functions that are being replaced (or just
    # removed outright).

    classes   = []
    functions = []

    for f in filenames:
        if re.search('libsbml.py', f) != None:
            functions = getFunctionNames(f)
        else:
            classes.append(f[f.rfind('/') + 1 : f.rfind('.')])

    print ("Processing " + args[1])
    print ("Will remove the following classes: " + ", ".join(classes))
    print ("Will remove the following functions: " + ", ".join(functions))

    skipping = False
    for line in input:
        if skipping and re.search(r'\A\S', line):
            skipping = False
        if skipping == False:
            for c in classes:
                if re.search(r'\Aclass ' + c + '\([^)]+\):', line):
                    skipping = True
                    continue
        if skipping == False:
            for f in functions:
                if re.search(r'\Adef ' + f, line):
                    skipping = True
                    continue
        if skipping:
            continue
        else:
            contents += line

    # Remove classes and functions marked @internal

    newContents     = ""
    pattern         = r'^\s*(def|class) \w+\([^)]*\): ?\n +"""(.*?)"""'
    inInternalClass = False

    for m in re.finditer(pattern, contents, flags=re.MULTILINE|re.DOTALL):
        if m.group(1) == 'class':
            if re.search('@internal', m.group(2)) != None:
                # Notice we won't even write this class or its methods out.
                inInternalClass = True
            else:
                inInternalClass = False
                newContents += m.group(0) + '\n'
        else:                               # it's a def
            if not inInternalClass and re.search('@internal', m.group(2)) == None:
                newContents += m.group(0) + '\n'

    # Append the contents of files we're using for substitutions.

    print ("Will append the contents of the following files: " + " ".join(filenames))
    for f in filenames:
        newContents += open(f, 'r').read() + '\n'

    print ("Writing output to " + args[2])
    output.write(newContents)


if __name__ == '__main__':
  main(sys.argv)



#
# @file    TestL3Reaction.py
# @brief   L3 Reaction unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestL3Reaction.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestL3Reaction(unittest.TestCase):

  global R
  R = None

  def setUp(self):
    self.R = libsbml.Reaction(3,1)
    if (self.R == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.R ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Reaction_NS(self):
    self.assertTrue( self.R.getNamespaces() != None )
    self.assertTrue( self.R.getNamespaces().getLength() == 1 )
    self.assertTrue((     "http://www.sbml.org/sbml/level3/version1/core" == self.R.getNamespaces().getURI(0) ))
    pass  

  def test_L3_Reaction_compartment(self):
    compartment =  "cell";
    self.assertEqual( False, self.R.isSetCompartment() )
    self.R.setCompartment(compartment)
    self.assertTrue(( compartment == self.R.getCompartment() ))
    self.assertEqual( True, self.R.isSetCompartment() )
    if (self.R.getCompartment() == compartment):
      pass    
    self.R.unsetCompartment()
    self.assertEqual( False, self.R.isSetCompartment() )
    if (self.R.getCompartment() != None):
      pass    
    pass  

  def test_L3_Reaction_create(self):
    self.assertTrue( self.R.getTypeCode() == libsbml.SBML_REACTION )
    self.assertTrue( self.R.getMetaId() == "" )
    self.assertTrue( self.R.getNotes() == None )
    self.assertTrue( self.R.getAnnotation() == None )
    self.assertTrue( self.R.getId() == "" )
    self.assertTrue( self.R.getName() == "" )
    self.assertTrue( self.R.getCompartment() == "" )
    self.assertTrue( self.R.getFast() == False )
    self.assertTrue( self.R.getReversible() == True )
    self.assertEqual( False, self.R.isSetId() )
    self.assertEqual( False, self.R.isSetName() )
    self.assertEqual( False, self.R.isSetCompartment() )
    self.assertEqual( False, self.R.isSetFast() )
    self.assertEqual( False, self.R.isSetReversible() )
    pass  

  def test_L3_Reaction_createWithNS(self):
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.sbml.org", "testsbml")
    sbmlns = libsbml.SBMLNamespaces(3,1)
    sbmlns.addNamespaces(xmlns)
    r = libsbml.Reaction(sbmlns)
    self.assertTrue( r.getTypeCode() == libsbml.SBML_REACTION )
    self.assertTrue( r.getMetaId() == "" )
    self.assertTrue( r.getNotes() == None )
    self.assertTrue( r.getAnnotation() == None )
    self.assertTrue( r.getLevel() == 3 )
    self.assertTrue( r.getVersion() == 1 )
    self.assertTrue( r.getNamespaces() != None )
    self.assertTrue( r.getNamespaces().getLength() == 2 )
    self.assertTrue( r.getId() == "" )
    self.assertTrue( r.getName() == "" )
    self.assertTrue( r.getCompartment() == "" )
    self.assertTrue( r.getFast() == False )
    self.assertTrue( r.getReversible() == True )
    self.assertEqual( False, r.isSetId() )
    self.assertEqual( False, r.isSetName() )
    self.assertEqual( False, r.isSetCompartment() )
    self.assertEqual( False, r.isSetFast() )
    self.assertEqual( False, r.isSetReversible() )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Reaction_fast(self):
    self.assertTrue( self.R.isSetFast() == False )
    self.R.setFast(True)
    self.assertTrue( self.R.getFast() == True )
    self.assertTrue( self.R.isSetFast() == True )
    self.R.setFast(False)
    self.assertTrue( self.R.getFast() == False )
    self.assertTrue( self.R.isSetFast() == True )
    pass  

  def test_L3_Reaction_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Reaction_hasRequiredAttributes(self):
    r = libsbml.Reaction(3,1)
    self.assertEqual( False, r.hasRequiredAttributes() )
    r.setId( "id")
    self.assertEqual( False, r.hasRequiredAttributes() )
    r.setFast(False)
    self.assertEqual( False, r.hasRequiredAttributes() )
    r.setReversible(False)
    self.assertEqual( True, r.hasRequiredAttributes() )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Reaction_id(self):
    id =  "mitochondria";
    self.assertEqual( False, self.R.isSetId() )
    self.R.setId(id)
    self.assertTrue(( id == self.R.getId() ))
    self.assertEqual( True, self.R.isSetId() )
    if (self.R.getId() == id):
      pass    
    pass  

  def test_L3_Reaction_name(self):
    name =  "My_Favorite_Factory";
    self.assertEqual( False, self.R.isSetName() )
    self.R.setName(name)
    self.assertTrue(( name == self.R.getName() ))
    self.assertEqual( True, self.R.isSetName() )
    if (self.R.getName() == name):
      pass    
    self.R.unsetName()
    self.assertEqual( False, self.R.isSetName() )
    if (self.R.getName() != None):
      pass    
    pass  

  def test_L3_Reaction_reversible(self):
    self.assertTrue( self.R.isSetReversible() == False )
    self.R.setReversible(True)
    self.assertTrue( self.R.getReversible() == True )
    self.assertTrue( self.R.isSetReversible() == True )
    self.R.setReversible(False)
    self.assertTrue( self.R.getReversible() == False )
    self.assertTrue( self.R.isSetReversible() == True )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestL3Reaction))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)




#!/usr/bin/env python
# -*- python-indent-offset: 2 -*-
#
# @file    doc-filter-python.py
# @brief   Post-process libSBML's Python doc strings for use by Doxygen.
# @author  Michael Hucka
#
# Usage: pythondocfilter.py libsbml.py > output.py
#
# This is designed to be used as the value of the INPUT_FILTER
# configuration variable in Doxygen.  This filter reads the standard input,
# on which it expects one file at a time fed to it by doxygen, then cooks
# the contents and writes the results to standard output.  The need for
# this is to do additional transformations that can't be done in swigdoc.py
# because they rely on having in hand the final output from SWIG.
#
# <!--------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright (C) 2013-2018 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#     3. University of Heidelberg, Heidelberg, Germany
#
# Copyright (C) 2009-2013 jointly by the following organizations: 
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#  
# Copyright (C) 2006-2008 by the California Institute of Technology,
#     Pasadena, CA, USA 
#  
# Copyright (C) 2002-2005 jointly by the following organizations: 
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. Japan Science and Technology Agency, Japan
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# ---------------------------------------------------------------------- -->*/

import sys, string, os.path, re

#
# Global variables.
#

libsbml_enums = []

#
# Helper functions.
#

def reformatDocString (match):
  text = match.group(1)

  # First, define some regexps we use more than once below.
  # The regexp matches signatures of the following form:
  #    foo()
  #    foo() -> result(arg, arg, ...)
  #    foo(arg, arg, ...) -> result(arg, arg, ...)

  sigLHS  = '\w+\([-\w()=&*:"<>?,.\n ]*\)'
  sigRHS  = '( -> [-\w()=&*:"<>?|, \t]+)?'
  sigLine = sigLHS + sigRHS

  # We start by fixing some wonkiness with the output from SWIG: it sometimes
  # doubles up the signature strings it puts at the top of the doc string.
  # Here we try to remove the duplicates.

  p = re.compile('(?P<sig>' + sigLine + ')\s+(?P=sig)', re.MULTILINE)
  text = p.sub(r'\1', text)

  # The following are the bits we add around the signature strings, assigned
  # to variables to make the subsequent code slightly more readable.

  intro  = '<span class="signatureTitle">Python method signature(s)</span>:\n'
  sStart = '<pre class="signature">%'
  sEnd   = '</pre>'

  # The next regexp matches multiple signatures.
  # This relies on the fact that the first line(s) (up to a blank line) in
  # every method documentation string is the signature of the method.
  # The \A at the beginning of the regexp forces it that way.

  sigRE  = '\A(\s*)((' + sigLine + '\s*)+)'

  # This matches when the signatures are the only things in a docstring.
  p = re.compile(sigRE + '\Z', re.MULTILINE)
  text = p.sub(r'\1' + r'\1' + sStart + r'\2' + sEnd, text)

  # This matches when the signatures are followed with more text.
  p = re.compile(sigRE + '^\s*$', re.MULTILINE)
  text = p.sub(r'\1' + r'\1' + sStart + r'\2' + sEnd + r'\1<p>', text)

  # This ditches the "self" part of the signature string.
  text = re.sub(r'\(\w* ?self\)',  '()', text)
  text = re.sub(r'\(\w* ?self, ',  '(',  text)

  # This fixes a weird translation by SWIG's doc string generator: it
  # seems to turn "char *" to "char" instead of "string".  In our code,
  # this is almost never correct.  So:
  p = re.compile('(' + sigLHS + ') -> char')
  text = p.sub(r'\1 -> string', text)

  # Exceptions to the previous rule:
  text = text.replace('getCharacter() -> string', 'getCharacter() -> char')

  # Prettify the arrow:
  newArrow = '@htmlonly ' + \
             '<span class="signatureArrow"> </span>' + \
             '@endhtmlonly'
  p = re.compile(' -> ')
  text = p.sub(r' ' + newArrow + ' ', text)

  # Now we do some final transformations.

  start  = '<pre class=["\']signature["\']>'      #" This comment is for Emacs.
  middle = '.*?'
  end    = '</pre>'

  # First, remove default value statements in the parameter list.  The
  # Doxygen output has method signatures like "foo(string x, bool y=False)",
  # but the "y" does not really have a default value in the code.  This is
  # misleading and people have complained, so:

  p = re.compile('(' + start + ')(' + middle + ')(' + end + ')', re.DOTALL)
  text = p.sub(remove_default_values, text)

  # Next, clean up whitespace in the method signature strings (and not the
  # rest of the doc body, because that will mess up code example blocks).

  p = re.compile(start + '(' + middle + ')' + end, re.DOTALL)
  text = p.sub(clean_up_spaces, text)

  # Next, bring up the brief description, if there is one, to make it the
  # first line of the doc string.

  brief = '\w[^.]+\.'
  p = re.compile('(' + start + middle + end + '\s*?)<p>\s*(' + brief + ')\s(.*)', re.DOTALL)
  text = p.sub(r'\2\n\n' + r'\1' + r'\3', text)

  # Crucial detail: need a '!' character after the opening triple quotes or
  # else Doxygen puts the entire docstring inside a verbatim environment.

  return "\"\"\"!" + text + "\"\"\""


def remove_default_values(match):
  new_middle = re.sub(r'([_a-zA-Z]\w*)=[_a-zA-Z]\w*', r'\1', match.group(2))
  return match.group(1) + new_middle + match.group(3)


def clean_up_spaces(match):
  normalized = re.sub(' +', ' ', match.group(0))  # Multiple spaces.
  normalized = re.sub('^ +', '', normalized, flags=re.MULTILINE) # Leading spaces.
  normalized = normalized.replace(' , ', ', ')    # Space before comma.
  normalized = normalized.replace('( ', '(')      # Space after paren.
  normalized = normalized.replace(' )', ')')      # Space before paren.
  return normalized


def filterDocStrings(contents):
  global libsbml_enums

  # Make the docstrings more readable.
  p = re.compile('\"\"\"(.+?)\"\"\"', re.DOTALL | re.MULTILINE)
  contents = p.sub(reformatDocString, contents)

  # Additional manipulations.

  # "Double" is called "float" in python.  There's no "double" in Python,
  # so there's no risk of damaging code here, but we have to be careful
  # about different contexts in which the word "double" might be used.
  contents = contents.replace(' double', " float")
  contents = contents.replace('(double', " (float")

  # Enumeration types are actually integers in the Python bindings.
  contents = re.sub(r'(\b' + r'\b|\b'.join(libsbml_enums) + r'\b)', 'long', contents)

  # We alter the names of some functions.
  contents = re.sub(r'SBML_parseFormula\b',        "parseFormula",    contents)
  contents = re.sub(r'SBML_formulaToString\b',     "formulaToString", contents)

  # Other type replacements.
  contents = re.sub(r'an unsigned int',          'a long integer ', contents)
  contents = re.sub(r'bool const\s*\&',          'bool ',           contents)
  contents = re.sub(r'char const\s*\*',          'long ',           contents)
  contents = re.sub(r'const bool\s*\&',          'bool ',           contents)
  contents = re.sub(r'const int\s*\&',           'int ',            contents)
  contents = re.sub(r'const long\s*\&',          'long ',           contents)
  contents = re.sub(r'const std.string\s*\&',    'string ',         contents)
  contents = re.sub(r'const std.string',         'string ',         contents)
  contents = re.sub(r'double const\s*\&',        'bool ',           contents)
  contents = re.sub(r'int const\s*&',            'bool ',           contents)
  contents = re.sub(r'SBMLConstructorException', 'ValueError ',     contents)
  contents = re.sub(r'long const\s*\&',          'bool ',           contents)
  contents = re.sub(r'unsigned int',             'long ',           contents)
  # Make sure to do the replacement for 'const' before the replacement for
  # 'char *', because in the SWIG output, there are things like 'char const *'.
  contents = re.sub(r'const ',                   ' ',               contents)
  contents = re.sub(r'char \*',                  'string ',         contents)
  contents = re.sub(r'string \*',                'string ',         contents)
  contents = re.sub(r'string\s*\&',              'string ',         contents)
  contents = re.sub(r'double \*',                'float ',          contents)
  contents = re.sub(r'double\s*\&',              'float ',          contents)
  contents = re.sub(r'float\s*\&',               'float ',          contents)
  contents = re.sub(r'bool\s*\&',                'bool ',           contents)
  contents = re.sub(r'long\s*\&',                'long ',           contents)
  contents = re.sub(r'int\s*\&',                 'int ',            contents)

  return contents


# The only reason this is a function and not inlined in filterContents()
# is the need to get match.group(0), which you can't do with Python's
# \number syntax in a regexp.  ("\0" is not interpreted as a group number.)

def hack_class_docstring(match):
  whole = match.group(0)
  indent = match.group(1)
  return whole + '\n' + indent + '##\n'


def filterContents (contents):
  """
  filterContents(contents) -> contents
  """

  # The following removes the space after the ':' in an __init__ definition
  # because otherwise, Doxygen 1.4.5's parser fails to match __init__
  # properly.  Clearly it's a bug in Doxygen.
  contents = re.sub('def __init__\(([^)]+)\): \n',
                    r'def __init__(\1):\n', contents)

  # The following adds a couple of comment characters after the doc string of
  # every class declaration.  Why, you ask?  Oh yes, let me tell you.
  # Because Doxygen 1.8.5 (possibly other versions too), when using @ingroup
  # and when producing output for Python, will incorrectly process the first
  # method that comes after a Python class declaration.  It (1) uses the
  # brief description from the class declaration as the brief description for
  # the method, and (2) files the method in a list of method members on the
  # page with all the classes defined in the group.  An example of the result
  # is a long list of clone() methods on the page describing one of our L3
  # package groups (e.g., for the libSBML 'comp' extension), with one clone()
  # method per class in the group, because for most of our classes, the first
  # method declared is clone().

  p = re.compile('^class\s+\w+\(\w+?\):\n(\s+)""".+?"""', re.MULTILINE|re.DOTALL)
  contents = p.sub(lambda match: hack_class_docstring(match), contents)

  return contents


def filterForDoxygen (contents):
  """
  filterForDoxygen(contents) -> contents

  Massage the content of a python file to better suit Doxygen's expectations.
  """
  contents = filterContents(contents)
  contents = filterDocStrings(contents)

  return contents


#
# Main driver.
#

def main (args):
  """Usage: pythondocfilter.py libsbml.py > output.py

  libsbml.py    pathname to the libsbml.py file produced by SWIG.

  This cooks the final output of our swigdoc.py + SWIG sequence for use
  with doxygen, to do additional transformations that can't be done in
  swigdoc.py because they rely on having in hand the final output from
  SWIG.  This only acts on files whose names end in .py.
  """

  global libsbml_enums

  if len(args) != 2:
    print(main.__doc__)
    sys.exit(1)

  # Check if the environment variable LIBSBML_CLASSES_LIST is set.
  # If it is, use its value as the path to the classes list file.
  # If not, use a default name.

  if os.environ.get('LIBSBML_CLASSES_LIST'):
    classes_list_file = os.environ.get('LIBSBML_CLASSES_LIST')
  else:
    classes_list_file = 'class-list.txt'

  # import time
  # debugstream = open('/tmp/fout-' + str(time.time()), 'w')

  istream         = open(classes_list_file, 'r')
  libsbml_classes = istream.read().splitlines()
  libsbml_enums   = filter(lambda c: c.endswith('_t'), libsbml_classes)
  istream.close()

  istream    = open(args[1], 'r')
  contents   = istream.read()
  istream.close()

  # Only process the content if it's Python.

  if re.search('.py$', args[1]):
    result = filterForDoxygen(contents)
    sys.stdout.write(result)
    # debugstream.write(result)
    # debugstream.close()
  else:
    sys.stdout.write(contents)

  sys.exit(0)


if __name__ == '__main__':
  main(sys.argv)



#
# @file    TestWriteL3SBML.py
# @brief   Write SBML unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestWriteL3SBML.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def util_NaN():
  z = 1e300
  z = z * z

  return z - z

def util_PosInf():
  z = 1e300
  z = z * z

  return z

def util_NegInf():
  z = 1e300
  z = z * z

  return -z 

def wrapString(s):
  return s
  pass

def LV_L3v1():
  return "level=\"3\" version=\"1\">\n"
  pass

def NS_L3v1():
  return "xmlns=\"http://www.sbml.org/sbml/level3/version1/core\" "
  pass

def SBML_END():
  return "</sbml>\n"
  pass

def SBML_START():
  return "<sbml "
  pass

def XML_START():
  return "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
  pass

def wrapSBML_L3v1(s):
  r = XML_START()
  r += SBML_START()
  r += NS_L3v1()
  r += LV_L3v1()
  r += s
  r += SBML_END()
  return r
  pass

def wrapXML(s):
  r = XML_START()
  r += s
  return r
  pass


class TestWriteL3SBML(unittest.TestCase):

  global S
  S = None
  global D
  D = None

  def equals(self, *x):
    if len(x) == 2:
      return x[0] == x[1]
    elif len(x) == 1:
      return x[0] == self.OSS.str()

  def setUp(self):
    self.D = libsbml.SBMLDocument()
    self.D.setLevelAndVersion(3,1,False)
    self.S = None
    pass  

  def tearDown(self):
    self.D = None
    self.S = None
    pass  

  def test_SBMLWriter_L3_create(self):
    w = libsbml.SBMLWriter()
    self.assertTrue( w != None )
    _dummyList = [ w ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_SBMLWriter_L3_setProgramName(self):
    w = libsbml.SBMLWriter()
    self.assertTrue( w != None )
    i = w.setProgramName( "sss")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    i = w.setProgramName("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    _dummyList = [ w ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_SBMLWriter_L3_setProgramVersion(self):
    w = libsbml.SBMLWriter()
    self.assertTrue( w != None )
    i = w.setProgramVersion( "sss")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    i = w.setProgramVersion("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    _dummyList = [ w ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_WriteL3SBML_Compartment(self):
    expected =  "<compartment id=\"A\" constant=\"true\"/>";
    c = self.D.createModel().createCompartment()
    c.setId("A")
    c.setConstant(True)
    self.assertEqual( True, self.equals(expected,c.toSBML()) )
    pass  

  def test_WriteL3SBML_Compartment_spatialDimensions(self):
    expected = "<compartment id=\"A\" spatialDimensions=\"2.1\" " + "constant=\"false\"/>";
    expected1 =  "<compartment id=\"A\" constant=\"false\"/>";
    c = self.D.createModel().createCompartment()
    c.setId("A")
    c.setConstant(False)
    c.setSpatialDimensions(2.1)
    self.assertEqual( True, self.equals(expected,c.toSBML()) )
    c.unsetSpatialDimensions()
    self.assertEqual( True, self.equals(expected1,c.toSBML()) )
    pass  

  def test_WriteL3SBML_Event(self):
    expected =  "<event id=\"e\" useValuesFromTriggerTime=\"true\"/>";
    e = self.D.createModel().createEvent()
    e.setId("e")
    e.setUseValuesFromTriggerTime(True)
    self.assertEqual( True, self.equals(expected,e.toSBML()) )
    pass  

  def test_WriteL3SBML_Event_full(self):
    expected = wrapString("<event useValuesFromTriggerTime=\"true\">\n" + 
    "  <trigger initialValue=\"true\" persistent=\"false\">\n" + 
    "    <math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n" + 
    "      <true/>\n" + 
    "    </math>\n" + 
    "  </trigger>\n" + 
    "  <priority>\n" + 
    "    <math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n" + 
    "      <cn type=\"integer\"> 2 </cn>\n" + 
    "    </math>\n" + 
    "  </priority>\n" + 
    "</event>")
    e = self.D.createModel().createEvent()
    e.setUseValuesFromTriggerTime(True)
    t = e.createTrigger()
    t.setInitialValue(True)
    t.setPersistent(False)
    math1 = libsbml.parseFormula("true")
    t.setMath(math1)
    p = e.createPriority()
    math2 = libsbml.parseFormula("2")
    p.setMath(math2)
    self.assertEqual( True, self.equals(expected,e.toSBML()) )
    pass  

  def test_WriteL3SBML_Event_useValues(self):
    expected = wrapString("<event id=\"e\" useValuesFromTriggerTime=\"false\">\n" + 
    "  <delay/>\n" + 
    "</event>")
    e = self.D.createModel().createEvent()
    e.setId("e")
    e.setUseValuesFromTriggerTime(False)
    e.createDelay()
    self.assertEqual( True, self.equals(expected,e.toSBML()) )
    pass  

  def test_WriteL3SBML_INF(self):
    expected = "<parameter id=\"p\" value=\"INF\"" + " constant=\"true\"/>";
    p = self.D.createModel().createParameter()
    p.setId("p")
    p.setValue(util_PosInf())
    p.setConstant(True)
    self.assertEqual( True, self.equals(expected,p.toSBML()) )
    pass  

  def test_WriteL3SBML_KineticLaw_ListOfParameters(self):
    expected = wrapString("<kineticLaw>\n" + 
    "  <listOfLocalParameters>\n" + 
    "    <localParameter id=\"n\" value=\"1.2\"/>\n" + 
    "  </listOfLocalParameters>\n" + 
    "</kineticLaw>")
    kl = self.D.createModel().createReaction().createKineticLaw()
    p = kl.createLocalParameter()
    p.setId("n")
    p.setValue(1.2)
    self.assertEqual( True, self.equals(expected,kl.toSBML()) )
    pass  

  def test_WriteL3SBML_Model(self):
    expected = wrapSBML_L3v1("  <model/>\n"  
    )
    m = self.D.createModel("")
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_Model_conversionFactor(self):
    expected = wrapSBML_L3v1("  <model conversionFactor=\"p\"/>\n"  
    )
    m = self.D.createModel("")
    m.setConversionFactor("p")
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_Model_otherUnits(self):
    expected = wrapSBML_L3v1("  <model volumeUnits=\"litre\" areaUnits=\"area\" lengthUnits=\"metre\"/>\n"  
    )
    m = self.D.createModel("")
    m.setVolumeUnits("litre")
    m.setAreaUnits("area")
    m.setLengthUnits("metre")
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_Model_substanceUnits(self):
    expected = wrapSBML_L3v1("  <model substanceUnits=\"mole\"/>\n"  
    )
    m = self.D.createModel("")
    m.setSubstanceUnits("mole")
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_Model_timeUnits(self):
    expected = wrapSBML_L3v1("  <model timeUnits=\"second\"/>\n"  
    )
    m = self.D.createModel("")
    m.setTimeUnits("second")
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_NaN(self):
    expected = "<parameter id=\"p\" value=\"NaN\"" + " constant=\"true\"/>";
    p = self.D.createModel().createParameter()
    p.setId("p")
    p.setValue(util_NaN())
    p.setConstant(True)
    self.assertEqual( True, self.equals(expected,p.toSBML()) )
    pass  

  def test_WriteL3SBML_NegINF(self):
    expected = "<parameter id=\"p\" value=\"-INF\"" + " constant=\"true\"/>";
    p = self.D.createModel().createParameter()
    p.setId("p")
    p.setValue(util_NegInf())
    p.setConstant(True)
    self.assertEqual( True, self.equals(expected,p.toSBML()) )
    pass  

  def test_WriteL3SBML_Parameter(self):
    expected = "<parameter id=\"Km1\" value=\"2.3\"" + " units=\"second\" constant=\"true\"/>";
    p = self.D.createModel().createParameter()
    p.setId("Km1")
    p.setValue(2.3)
    p.setUnits("second")
    p.setConstant(True)
    self.assertEqual( True, self.equals(expected,p.toSBML()) )
    pass  

  def test_WriteL3SBML_Priority(self):
    expected =  "<priority/>";
    p = self.D.createModel().createEvent().createPriority()
    self.assertEqual( True, self.equals(expected,p.toSBML()) )
    pass  

  def test_WriteL3SBML_Reaction(self):
    expected = "<reaction id=\"r\" reversible=\"false\"" + " fast=\"true\"/>";
    r = self.D.createModel().createReaction()
    r.setId("r")
    r.setReversible(False)
    r.setFast(True)
    self.assertEqual( True, self.equals(expected,r.toSBML()) )
    pass  

  def test_WriteL3SBML_Reaction_compartment(self):
    expected = "<reaction id=\"r\" reversible=\"false\"" + " fast=\"true\" compartment=\"c\"/>";
    expected1 = "<reaction id=\"r\" reversible=\"false\"" + " fast=\"true\"/>";
    r = self.D.createModel().createReaction()
    r.setId("r")
    r.setReversible(False)
    r.setFast(True)
    r.setCompartment("c")
    self.assertEqual( True, self.equals(expected,r.toSBML()) )
    r.unsetCompartment()
    self.assertEqual( True, self.equals(expected1,r.toSBML()) )
    pass  

  def test_WriteL3SBML_Reaction_full(self):
    expected = wrapString("<reaction id=\"v1\" reversible=\"true\" fast=\"false\">\n" + 
    "  <listOfReactants>\n" + 
    "    <speciesReference species=\"x0\"/>\n" + 
    "  </listOfReactants>\n" + 
    "  <listOfProducts>\n" + 
    "    <speciesReference species=\"s1\"/>\n" + 
    "  </listOfProducts>\n" + 
    "  <listOfModifiers>\n" + 
    "    <modifierSpeciesReference species=\"m1\"/>\n" + 
    "  </listOfModifiers>\n" + 
    "  <kineticLaw>\n" + 
    "    <math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n" + 
    "      <apply>\n" + 
    "        <divide/>\n" + 
    "        <apply>\n" + 
    "          <times/>\n" + 
    "          <ci> vm </ci>\n" + 
    "          <ci> s1 </ci>\n" + 
    "        </apply>\n" + 
    "        <apply>\n" + 
    "          <plus/>\n" + 
    "          <ci> km </ci>\n" + 
    "          <ci> s1 </ci>\n" + 
    "        </apply>\n" + 
    "      </apply>\n" + 
    "    </math>\n" + 
    "  </kineticLaw>\n" + 
    "</reaction>")
    self.D.createModel()
    r = self.D.getModel().createReaction()
    r.setId("v1")
    r.setReversible(True)
    r.setFast(False)
    r.createReactant().setSpecies("x0")
    r.createProduct().setSpecies("s1")
    r.createModifier().setSpecies("m1")
    r.createKineticLaw().setFormula("(vm * s1)/(km + s1)")
    self.assertEqual( True, self.equals(expected,r.toSBML()) )
    pass  

  def test_WriteL3SBML_SBMLDocument_L3v1(self):
    expected = wrapXML("<sbml xmlns=\"http://www.sbml.org/sbml/level3/version1/core\" " + "level=\"3\" version=\"1\"/>\n")
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_Species(self):
    expected = wrapString("<species id=\"Ca2\" compartment=\"cell\" initialAmount=\"0.7\"" + 
    " substanceUnits=\"mole\" hasOnlySubstanceUnits=\"false\"" + 
    " boundaryCondition=\"true\" constant=\"true\"/>")
    s = self.D.createModel().createSpecies()
    s.setId("Ca2")
    s.setCompartment("cell")
    s.setInitialAmount(0.7)
    s.setUnits("mole")
    s.setBoundaryCondition(True)
    s.setHasOnlySubstanceUnits(False)
    s.setConstant(True)
    self.assertEqual( True, self.equals(expected,s.toSBML()) )
    pass  

  def test_WriteL3SBML_SpeciesReference(self):
    expected = "<speciesReference species=\"s\"" + " stoichiometry=\"3\" constant=\"true\"/>";
    sr = self.D.createModel().createReaction().createReactant()
    sr.setSpecies("s")
    sr.setStoichiometry(3)
    sr.setConstant(True)
    self.assertEqual( True, self.equals(expected,sr.toSBML()) )
    pass  

  def test_WriteL3SBML_Species_conversionFactor(self):
    expected = wrapString("<species id=\"Ca2\" compartment=\"cell\"" + 
    " hasOnlySubstanceUnits=\"false\"" + 
    " boundaryCondition=\"true\" constant=\"true\"" + 
    " conversionFactor=\"p\"/>")
    expected1 = wrapString("<species id=\"Ca2\" compartment=\"cell\"" + 
    " hasOnlySubstanceUnits=\"false\"" + 
    " boundaryCondition=\"true\" constant=\"true\"/>")
    s = self.D.createModel().createSpecies()
    s.setId("Ca2")
    s.setCompartment("cell")
    s.setBoundaryCondition(True)
    s.setHasOnlySubstanceUnits(False)
    s.setConstant(True)
    s.setConversionFactor("p")
    self.assertEqual( True, self.equals(expected,s.toSBML()) )
    s.unsetConversionFactor()
    self.assertEqual( True, self.equals(expected1,s.toSBML()) )
    pass  

  def test_WriteL3SBML_Trigger(self):
    expected =  "<trigger/>";
    t = self.D.createModel().createEvent().createTrigger()
    self.assertEqual( True, self.equals(expected,t.toSBML()) )
    pass  

  def test_WriteL3SBML_Trigger_initialValue(self):
    expected =  "<trigger initialValue=\"false\" persistent=\"true\"/>";
    t = self.D.createModel().createEvent().createTrigger()
    t.setInitialValue(False)
    t.setPersistent(True)
    self.assertEqual( True, self.equals(expected,t.toSBML()) )
    pass  

  def test_WriteL3SBML_Trigger_persistent(self):
    expected =  "<trigger initialValue=\"true\" persistent=\"false\"/>";
    t = self.D.createModel().createEvent().createTrigger()
    t.setPersistent(False)
    t.setInitialValue(True)
    self.assertEqual( True, self.equals(expected,t.toSBML()) )
    pass  

  def test_WriteL3SBML_Unit(self):
    expected = "<unit kind=\"kilogram\" exponent=\"0.2\"" + " scale=\"-3\" multiplier=\"3.2\"/>";
    u = self.D.createModel().createUnitDefinition().createUnit()
    u.setKind(libsbml.UNIT_KIND_KILOGRAM)
    exp = 0.2
    u.setExponent(exp)
    u.setScale(-3)
    u.setMultiplier(3.2)
    self.assertEqual( True, self.equals(expected,u.toSBML()) )
    pass  

  def test_WriteL3SBML_UnitDefinition(self):
    expected = wrapString("<unitDefinition id=\"myUnit\">\n" + 
    "  <listOfUnits>\n" + 
    "    <unit kind=\"mole\" exponent=\"1\" scale=\"0\" multiplier=\"1.8\"/>\n" + 
    "  </listOfUnits>\n" + 
    "</unitDefinition>")
    ud = self.D.createModel().createUnitDefinition()
    ud.setId("myUnit")
    u1 = ud.createUnit()
    u1.setKind(libsbml.UnitKind_forName("mole"))
    u1.setMultiplier(1.8)
    u1.setScale(0)
    u1.setExponent(1)
    self.assertEqual( True, self.equals(expected,ud.toSBML()) )
    pass  

  def test_WriteL3SBML_Unit_noValues(self):
    expected =  "<unit/>";
    u = self.D.createModel().createUnitDefinition().createUnit()
    self.assertEqual( True, self.equals(expected,u.toSBML()) )
    pass  

  def test_WriteL3SBML_elements(self):
    expected = wrapSBML_L3v1("  <model>\n" + 
    "    <listOfFunctionDefinitions>\n" + 
    "      <functionDefinition/>\n" + 
    "    </listOfFunctionDefinitions>\n" + 
    "    <listOfUnitDefinitions>\n" + 
    "      <unitDefinition/>\n" + 
    "    </listOfUnitDefinitions>\n" + 
    "    <listOfCompartments>\n" + 
    "      <compartment/>\n" + 
    "    </listOfCompartments>\n" + 
    "    <listOfSpecies>\n" + 
    "      <species/>\n" +
    "    </listOfSpecies>\n" + 
    "    <listOfParameters>\n" + 
    "      <parameter/>\n" + 
    "    </listOfParameters>\n" + 
    "    <listOfInitialAssignments>\n" + 
    "      <initialAssignment/>\n" + 
    "    </listOfInitialAssignments>\n" + 
    "    <listOfRules>\n" + 
    "      <algebraicRule/>\n" + 
    "    </listOfRules>\n" + 
    "    <listOfConstraints>\n" + 
    "      <constraint/>\n" + 
    "    </listOfConstraints>\n" + 
    "    <listOfReactions>\n" + 
    "      <reaction/>\n" + 
    "    </listOfReactions>\n" + 
    "    <listOfEvents>\n" + 
    "      <event/>\n" + 
    "    </listOfEvents>\n" + 
    "  </model>\n")
    m = self.D.createModel()
    m.createUnitDefinition()
    m.createFunctionDefinition()
    m.createCompartment()
    m.createEvent()
    m.createParameter()
    m.createAlgebraicRule()
    m.createInitialAssignment()
    m.createConstraint()
    m.createReaction()
    m.createSpecies()
    self.S = libsbml.writeSBMLToString(self.D)
    self.assertEqual( True, self.equals(expected,self.S) )
    pass  

  def test_WriteL3SBML_error(self):
    d = libsbml.SBMLDocument()
    w = libsbml.SBMLWriter()
    self.assertEqual( False, w.writeSBML(d, "/tmp/impossible/path/should/fail") )
    self.assertTrue( d.getNumErrors() == 1 )
    self.assertTrue( d.getError(0).getErrorId() == libsbml.XMLFileUnwritable )
    d = None
    w = None
    pass  

  def test_WriteL3SBML_locale(self):
    expected = "<parameter id=\"p\" value=\"3.31\"" + " constant=\"true\"/>";
    p = self.D.createModel().createParameter()
    p.setId("p")
    p.setValue(3.31)
    p.setConstant(True)
    self.assertEqual( True, self.equals(expected,p.toSBML()) )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestWriteL3SBML))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



from libsbml import *

arraysNs = ArraysPkgNamespaces();
doc = SBMLDocument(arraysNs);
doc.setPackageRequired("arrays", True);
model = doc.createModel();

# create compartment
comp = model.createCompartment();
comp.setMetaId("dd");
comp.setId("s");
comp.setConstant(True);

# set dimensions
compPlugin = comp.getPlugin("arrays");
dim = compPlugin.createDimension();
dim.setId("i");
dim.setSize("n");

# create species
species = model.createSpecies();
species.setId("A");
species.setCompartment("s");
species.setHasOnlySubstanceUnits(False);
species.setBoundaryCondition(False);
species.setConstant(False);

splugin = species.getPlugin("arrays");
dim = splugin.createDimension();
dim.setId("i");
dim.setSize("n");

species = model.createSpecies();
species.setId("B");
species.setCompartment("s");
species.setHasOnlySubstanceUnits(False);
species.setBoundaryCondition(False);
species.setConstant(False);

splugin = species.getPlugin("arrays");
dim = splugin.createDimension();
dim.setId("i");
dim.setSize("n");

species = model.createSpecies();
species.setId("C");
species.setCompartment("s");
species.setHasOnlySubstanceUnits(False);
species.setBoundaryCondition(False);
species.setConstant(False);

splugin = species.getPlugin("arrays");
dim = splugin.createDimension();
dim.setId("i");
dim.setSize("n");

# create parameter
param = model.createParameter();
param.setId("n");
param.setValue(100);
param.setConstant(True);

# create reaction
reaction = model.createReaction();
reaction.setId("reaction1");
reaction.setReversible(False);
reaction.setFast(False);

reactionPlugin = reaction.getPlugin("arrays");
dim = reactionPlugin.createDimension();
dim.setId("i");
dim.setSize("n");

speciesRef = reaction.createReactant();
speciesRef.setSpecies("A");
speciesRef.setConstant(False);
refPlugin = speciesRef.getPlugin("arrays");
index = refPlugin.createIndex();
ast = ASTNode(AST_LINEAR_ALGEBRA_SELECTOR);
ci1 = ASTNode(AST_NAME);
ci1.setName("A");
ast.addChild(ci1);
ci2 = ASTNode(AST_NAME);
ci2.setName("i");
ast.addChild(ci2);
index.setMath(ast);

speciesRef = reaction.createProduct();
speciesRef.setSpecies("C");
speciesRef.setConstant(False);
refPlugin = speciesRef.getPlugin("arrays");
index = refPlugin.createIndex();
ast = ASTNode(AST_LINEAR_ALGEBRA_SELECTOR);
ci1 = ASTNode(AST_NAME);
ci1.setName("C");
ast.addChild(ci1);
ci2 = ASTNode(AST_NAME);
ci2.setName("i");
ast.addChild(ci2);
index.setMath(ast);

writeSBMLToFile(doc, "arrays1.xml");



#
# @file    TestL3SpeciesReference.py
# @brief   L3 SpeciesReference unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestL3SpeciesReference.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def isnan(x):
  return (x != x)
  pass

class TestL3SpeciesReference(unittest.TestCase):

  global SR
  SR = None

  def setUp(self):
    self.SR = libsbml.SpeciesReference(3,1)
    if (self.SR == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.SR ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_SpeciesReference_NS(self):
    self.assertTrue( self.SR.getNamespaces() != None )
    self.assertTrue( self.SR.getNamespaces().getLength() == 1 )
    self.assertTrue((     "http://www.sbml.org/sbml/level3/version1/core" == self.SR.getNamespaces().getURI(0) ))
    pass  

  def test_L3_SpeciesReference_constant(self):
    self.assertTrue( self.SR.isSetConstant() == False )
    self.SR.setConstant(True)
    self.assertTrue( self.SR.getConstant() == True )
    self.assertTrue( self.SR.isSetConstant() == True )
    self.SR.setConstant(False)
    self.assertTrue( self.SR.getConstant() == False )
    self.assertTrue( self.SR.isSetConstant() == True )
    pass  

  def test_L3_SpeciesReference_create(self):
    self.assertTrue( self.SR.getTypeCode() == libsbml.SBML_SPECIES_REFERENCE )
    self.assertTrue( self.SR.getMetaId() == "" )
    self.assertTrue( self.SR.getNotes() == None )
    self.assertTrue( self.SR.getAnnotation() == None )
    self.assertTrue( self.SR.getId() == "" )
    self.assertTrue( self.SR.getName() == "" )
    self.assertTrue( self.SR.getSpecies() == "" )
    self.assertEqual( True, isnan(self.SR.getStoichiometry()) )
    self.assertTrue( self.SR.getConstant() == False )
    self.assertEqual( False, self.SR.isSetId() )
    self.assertEqual( False, self.SR.isSetName() )
    self.assertEqual( False, self.SR.isSetSpecies() )
    self.assertEqual( False, self.SR.isSetStoichiometry() )
    self.assertEqual( False, self.SR.isSetConstant() )
    pass  

  def test_L3_SpeciesReference_createWithNS(self):
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.sbml.org", "testsbml")
    sbmlns = libsbml.SBMLNamespaces(3,1)
    sbmlns.addNamespaces(xmlns)
    sr = libsbml.SpeciesReference(sbmlns)
    self.assertTrue( sr.getTypeCode() == libsbml.SBML_SPECIES_REFERENCE )
    self.assertTrue( sr.getMetaId() == "" )
    self.assertTrue( sr.getNotes() == None )
    self.assertTrue( sr.getAnnotation() == None )
    self.assertTrue( sr.getLevel() == 3 )
    self.assertTrue( sr.getVersion() == 1 )
    self.assertTrue( sr.getNamespaces() != None )
    self.assertTrue( sr.getNamespaces().getLength() == 2 )
    self.assertTrue( sr.getId() == "" )
    self.assertTrue( sr.getName() == "" )
    self.assertTrue( sr.getSpecies() == "" )
    self.assertEqual( True, isnan(sr.getStoichiometry()) )
    self.assertTrue( sr.getConstant() == False )
    self.assertEqual( False, sr.isSetId() )
    self.assertEqual( False, sr.isSetName() )
    self.assertEqual( False, sr.isSetSpecies() )
    self.assertEqual( False, sr.isSetStoichiometry() )
    self.assertEqual( False, sr.isSetConstant() )
    _dummyList = [ sr ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_SpeciesReference_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_SpeciesReference_hasRequiredAttributes(self):
    sr = libsbml.SpeciesReference(3,1)
    self.assertEqual( False, sr.hasRequiredAttributes() )
    sr.setSpecies( "id")
    self.assertEqual( False, sr.hasRequiredAttributes() )
    sr.setConstant(False)
    self.assertEqual( True, sr.hasRequiredAttributes() )
    _dummyList = [ sr ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_SpeciesReference_id(self):
    id =  "mitochondria";
    self.assertEqual( False, self.SR.isSetId() )
    self.SR.setId(id)
    self.assertTrue(( id == self.SR.getId() ))
    self.assertEqual( True, self.SR.isSetId() )
    if (self.SR.getId() == id):
      pass    
    pass  

  def test_L3_SpeciesReference_name(self):
    name =  "My_Favorite_Factory";
    self.assertEqual( False, self.SR.isSetName() )
    self.SR.setName(name)
    self.assertTrue(( name == self.SR.getName() ))
    self.assertEqual( True, self.SR.isSetName() )
    if (self.SR.getName() == name):
      pass    
    self.SR.unsetName()
    self.assertEqual( False, self.SR.isSetName() )
    if (self.SR.getName() != None):
      pass    
    pass  

  def test_L3_SpeciesReference_species(self):
    species =  "cell";
    self.assertEqual( False, self.SR.isSetSpecies() )
    self.SR.setSpecies(species)
    self.assertTrue(( species == self.SR.getSpecies() ))
    self.assertEqual( True, self.SR.isSetSpecies() )
    if (self.SR.getSpecies() == species):
      pass    
    pass  

  def test_L3_SpeciesReference_stoichiometry(self):
    stoichiometry = 0.2
    self.assertEqual( False, self.SR.isSetStoichiometry() )
    self.assertEqual( True, isnan(self.SR.getStoichiometry()) )
    self.SR.setStoichiometry(stoichiometry)
    self.assertTrue( self.SR.getStoichiometry() == stoichiometry )
    self.assertEqual( True, self.SR.isSetStoichiometry() )
    self.SR.unsetStoichiometry()
    self.assertEqual( False, self.SR.isSetStoichiometry() )
    self.assertEqual( True, isnan(self.SR.getStoichiometry()) )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestL3SpeciesReference))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
# @file    createStatisticsExample.py
# @brief   SBML distrib example
# @author  Sarah Keating
#
#
# <!--------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http:#sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright (C) 2009-2013 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
#
# Copyright (C) 2006-2008 by the California Institute of Technology,
#     Pasadena, CA, USA 
#
# Copyright (C) 2002-2005 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. Japan Science and Technology Agency, Japan
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http:#sbml.org/software/libsbml/license.html
# ------------------------------------------------------------------------ -->


from libsbml import *

sbmlns = SBMLNamespaces(3, 1, "distrib", 1);
document = SBMLDocument(sbmlns);

# set the required attribute to true
docPlug = document.getPlugin("distrib");
docPlug.setRequired(True);

# create the Model

model = document.createModel();

# create the Parameter

p = model.createParameter();
p.setId("V");
p.setConstant(true);

#
# Get a DistribSBasePlugin object plugged in the parameter object.
#
pPlugin = p.getPlugin("distrib");

# create a Uncertainty object
uncert = pPlugin.createUncertainty();

# create the UncertMLNode object
uncertML = libsbml.createDistributionNode("Statistics", "Mean, Variance", "V_pop, V_omega");

uncert.setUncertML(uncertML);

writeSBMLToFile(document, "distrib_example1.xml");



#
# @file    TestModelCreator_newSetters.py
# @brief   ModelCreator unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/annotation/test/TestModelCreator_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestModelCreator_newSetters(unittest.TestCase):


  def test_ModelCreator_setEmail(self):
    mc = libsbml.ModelCreator()
    self.assertTrue( mc != None )
    i = mc.setEmail( "Keating")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetEmail() == True )
    self.assertTrue((  "Keating" == mc.getEmail() ))
    i = mc.setEmail( "")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetEmail() == False )
    i = mc.setEmail( "Keating")
    self.assertTrue( mc.isSetEmail() == True )
    i = mc.unsetEmail()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetEmail() == False )
    _dummyList = [ mc ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_ModelCreator_setFamilyName(self):
    mc = libsbml.ModelCreator()
    self.assertTrue( mc != None )
    i = mc.setFamilyName( "Keating")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetFamilyName() == True )
    self.assertTrue((  "Keating" == mc.getFamilyName() ))
    i = mc.setFamilyName( "")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetFamilyName() == False )
    i = mc.setFamilyName( "Keating")
    self.assertTrue( mc.isSetFamilyName() == True )
    i = mc.unsetFamilyName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetFamilyName() == False )
    _dummyList = [ mc ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_ModelCreator_setGivenName(self):
    mc = libsbml.ModelCreator()
    self.assertTrue( mc != None )
    i = mc.setGivenName( "Sarah")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetGivenName() == True )
    self.assertTrue((  "Sarah" == mc.getGivenName() ))
    i = mc.setGivenName( "")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetGivenName() == False )
    i = mc.setGivenName( "Sarah")
    self.assertTrue( mc.isSetGivenName() == True )
    i = mc.unsetGivenName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetGivenName() == False )
    _dummyList = [ mc ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_ModelCreator_setOrganization(self):
    mc = libsbml.ModelCreator()
    self.assertTrue( mc != None )
    i = mc.setOrganization( "Caltech")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetOrganization() == True )
    self.assertTrue((  "Caltech" == mc.getOrganization() ))
    i = mc.setOrganization( "")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetOrganization() == False )
    i = mc.setOrganization( "Caltech")
    self.assertTrue( mc.isSetOrganization() == True )
    i = mc.unsetOrganization()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( mc.isSetOrganization() == False )
    _dummyList = [ mc ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestModelCreator_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)




class ostringstream(ostream):
    """Wrapper class for the C++ standard file stream <code>ofstream</code>.

    The C++ <code>ostringstream</code> ('output string stream') provides an
    interface for writing data to strings as output streams.  This Python
    class, <code>ostringstream</code>, wraps the C++
    <code>ostringstream</code> and provides an interface to it.

    This class may be useful because some libSBML methods accept an argument
    for indicating where to send text string output.  An example is the
    SBMLDocument#printErrors() method.  The methods use
    C++ style streams and not Python stream objects.  The
    <code>ostringstream</code> object exists to bridge the Python and
    underlying native implementation.  It is a simple wrapper around the
    underlying stream object.
    """

    def __init__(self):
        """
        <span class='variant-sig-heading'>Method variant with the following signature</span>:
         <pre class='signature'>__init__(self) -> string</pre>

        Constructor for ostringstream objects.
        """

    def str(self, *args):
        """
        This method has multiple variants; they differ in the arguments
         they accept.  Each variant is described separately below.

        @par
        <hr>
        <span class='variant-sig-heading'>Method variant with the following signature</span>:
         <pre class='signature'>str(ostringstream self) -> string</pre>

        Returns the copy of the string object currently associated
        with this <code>ostringstream</code> buffer.

        @return a copy of the string object for this stream.

        @par
        <hr>
        <span class='variant-sig-heading'>Method variant with the following signature</span>:
         <pre class='signature'>str(ostringstream self, string s)</pre>

        Sets string @p s to the string object currently assosiated with
        this stream buffer.

        @param s the string to write to this stream.
        """



#!/usr/bin/env python

import unittest
import rewrite_pydoc
import tempfile
import os

# The approach here, using the for loop and the 'ch' function, came from a
# reply to a StackOverflow question by one Adrian Panasiuk on 2009-07-28:
# http://stackoverflow.com/questions/1193909/pythons-unittest-and-dynamic-creation-of-test-cases

class Tests(unittest.TestCase):

    def check(self, testinput, testoutput):
        args       = rewrite_pydoc.parse_cmdline(['-f', testinput, '-o', 'ignored'])
        fname      = rewrite_pydoc.get_input_file_name(args)
        contents   = rewrite_pydoc.read_file_contents(fname)
        rewritten  = rewrite_pydoc.rewrite(contents, '../../../../docs/src/common-text',
                                           '../../../../docs/src/common-graphics', False)
        expected   = open(testoutput, 'r').read()
        self.assertEqual(rewritten, expected)


for i in range(2, 1000):
    testinput  = 'test/data/%.3d.i' % i
    testoutput = 'test/data/%.3d_expected.i' % i
    if os.path.exists(testinput):
        def ch(testinput, testoutput):
            return lambda self: self.check(testinput, testoutput)
        setattr(Tests, "test_%.3d" % i, ch(testinput, testoutput))

def main():
    unittest.main()

if __name__ == '__main__':
    main()



#
# @file    TestXMLErrorC.py
# @brief   XMLError unit tests, C version
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/xml/test/TestXMLErrorC.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestXMLErrorC(unittest.TestCase):


  def test_XMLError_create_C(self):
    error = libsbml.XMLError()
    self.assertTrue( error != None )
    self.assertTrue( error.isInfo() == False )
    self.assertTrue( error.isWarning() == False )
    self.assertTrue( error.isError() == False )
    self.assertTrue( error.isFatal() == True )
    _dummyList = [ error ]; _dummyList[:] = []; del _dummyList
    error = libsbml.XMLError(12345, "My message")
    self.assertTrue( (  "My message" != error.getMessage() ) == False )
    self.assertTrue( error.getErrorId() == 12345 )
    _dummyList = [ error ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLError_variablesAsStrings(self):
    error = libsbml.XMLError(1003, "")
    self.assertTrue( error.getErrorId() == 1003 )
    self.assertTrue( error.getSeverity() == libsbml.LIBSBML_SEV_ERROR )
    self.assertTrue((  "Error" == error.getSeverityAsString() ))
    self.assertTrue( error.getCategory() == libsbml.LIBSBML_CAT_XML )
    self.assertTrue((  "XML content" == error.getCategoryAsString() ))
    _dummyList = [ error ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestXMLErrorC))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)




#
# @file    TestParameterRule.py
# @brief   ParameterRule unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestParameterRule.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestParameterRule(unittest.TestCase):

  global PR
  PR = None

  def setUp(self):
    self.PR = libsbml.AssignmentRule(1,2)
    self.PR.setL1TypeCode(libsbml.SBML_PARAMETER_RULE)
    if (self.PR == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.PR ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_ParameterRule_create(self):
    self.assertTrue( self.PR.getTypeCode() == libsbml.SBML_ASSIGNMENT_RULE )
    self.assertTrue( self.PR.getL1TypeCode() == libsbml.SBML_PARAMETER_RULE )
    self.assertTrue( self.PR.getNotes() == None )
    self.assertTrue( self.PR.getAnnotation() == None )
    self.assertTrue( self.PR.getFormula() == "" )
    self.assertTrue( self.PR.getUnits() == "" )
    self.assertTrue( self.PR.getVariable() == "" )
    self.assertTrue( self.PR.getType() == libsbml.RULE_TYPE_SCALAR )
    self.assertEqual( False, self.PR.isSetVariable() )
    self.assertEqual( False, self.PR.isSetUnits() )
    pass  

  def test_ParameterRule_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_ParameterRule_setName(self):
    name =  "cell";
    self.PR.setVariable(name)
    self.assertTrue(( name == self.PR.getVariable() ))
    self.assertEqual( True, self.PR.isSetVariable() )
    if (self.PR.getVariable() == name):
      pass    
    c = self.PR.getVariable()
    self.PR.setVariable(c)
    self.assertTrue(( name == self.PR.getVariable() ))
    self.PR.setVariable("")
    self.assertEqual( False, self.PR.isSetVariable() )
    if (self.PR.getVariable() != None):
      pass    
    pass  

  def test_ParameterRule_setUnits(self):
    units =  "cell";
    self.PR.setUnits(units)
    self.assertTrue(( units == self.PR.getUnits() ))
    self.assertEqual( True, self.PR.isSetUnits() )
    if (self.PR.getUnits() == units):
      pass    
    self.PR.setUnits(self.PR.getUnits())
    self.assertTrue(( units == self.PR.getUnits() ))
    self.PR.setUnits("")
    self.assertEqual( False, self.PR.isSetUnits() )
    if (self.PR.getUnits() != None):
      pass    
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestParameterRule))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
##
## @file    convertLayout.py
## @author  Frank T. Bergmann
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->

import sys
from libsbml import *

def convertDocToL2(doc, outputFile):
  layoutNsUri = "http://projects.eml.org/bcb/sbml/level2"
  layoutNs = LayoutPkgNamespaces(2, 4)
  renderNsUri = "http://projects.eml.org/bcb/sbml/render/level2"
  renderNs = RenderPkgNamespaces(2, 4)

  prop = ConversionProperties(SBMLNamespaces(2,4))
  prop.addOption('strict', False)
  prop.addOption('setLevelAndVersion', True)
  prop.addOption('ignorePackages', True)
  doc.convert(prop)


  docPlugin = doc.getPlugin("layout")
  if docPlugin is not None:
    docPlugin.setElementNamespace(layoutNsUri)

  doc.getSBMLNamespaces().removePackageNamespace(3, 1, "layout", 1)
  doc.getSBMLNamespaces().addPackageNamespace("layout", 1)

  rdocPlugin = doc.getPlugin("render")
  if rdocPlugin is not None:
    rdocPlugin.setElementNamespace(renderNsUri)

  doc.getSBMLNamespaces().removePackageNamespace(3, 1, "render", 1)
  doc.getSBMLNamespaces().addPackageNamespace("render", 1)

  writeSBMLToFile(doc, outputFile)

def convertDocToL3(doc, outputFile):
  layoutNsUri = "http://www.sbml.org/sbml/level3/version1/layout/version1"
  layoutNs = LayoutPkgNamespaces(3, 1)
  renderNsUri = "http://www.sbml.org/sbml/level3/version1/render/version1"
  renderNs = RenderPkgNamespaces(3, 1)

  prop = ConversionProperties(SBMLNamespaces(3,1))
  prop.addOption('strict', False)
  prop.addOption('setLevelAndVersion', True)
  prop.addOption('ignorePackages', True)
  doc.convert(prop)


  docPlugin = doc.getPlugin("layout")
  if docPlugin is not None:
    docPlugin.setElementNamespace(layoutNsUri)

  doc.getSBMLNamespaces().removePackageNamespace(3, 1, "layout", 1)
  doc.getSBMLNamespaces().addPackageNamespace("layout", 1)

  rdocPlugin = doc.getPlugin("render")
  if rdocPlugin is not None:
    rdocPlugin.setElementNamespace(renderNsUri)

  doc.getSBMLNamespaces().removePackageNamespace(3, 1, "render", 1)
  doc.getSBMLNamespaces().addPackageNamespace("render", 1)

  writeSBMLToFile(doc, outputFile)

def convertFileToL2(inputFile, outputFile):
  doc  = readSBMLFromFile(inputFile)
  convertDocToL2(doc, outputFile)

def convertFileToL3(inputFile, outputFile):
  doc  = readSBMLFromFile(inputFile)
  convertDocToL3(doc, outputFile)

def convertFile(inputFile, outputFile):
  doc  = readSBMLFromFile(inputFile)
  if doc.getLevel() == 3:
    convertDocToL2(doc, outputFile)
  else:
    convertDocToL3(doc, outputFile)
  
  
if __name__ == '__main__':
  if len(sys.argv) != 3:
     print("""

     usage: convertLayout <input file> <output file>

     """)
     sys.exit(1)

  convertFile(sys.argv[1], sys.argv[2])



#
# @file    TestFunctionDefinition.py
# @brief   SBML FunctionDefinition unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestFunctionDefinition.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestFunctionDefinition(unittest.TestCase):

  global FD
  FD = None

  def setUp(self):
    self.FD = libsbml.FunctionDefinition(2,4)
    if (self.FD == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.FD ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_FunctionDefinition_create(self):
    self.assertTrue( self.FD.getTypeCode() == libsbml.SBML_FUNCTION_DEFINITION )
    self.assertTrue( self.FD.getMetaId() == "" )
    self.assertTrue( self.FD.getNotes() == None )
    self.assertTrue( self.FD.getAnnotation() == None )
    self.assertTrue( self.FD.getId() == "" )
    self.assertTrue( self.FD.getName() == "" )
    self.assertTrue( self.FD.getMath() == None )
    pass  

  def test_FunctionDefinition_createWith(self):
    math = libsbml.parseFormula("lambda(x, x^3)")
    fd = libsbml.FunctionDefinition(2,4)
    fd.setId( "pow3")
    fd.setMath(math)
    self.assertTrue( fd.getTypeCode() == libsbml.SBML_FUNCTION_DEFINITION )
    self.assertTrue( fd.getMetaId() == "" )
    self.assertTrue( fd.getNotes() == None )
    self.assertTrue( fd.getAnnotation() == None )
    self.assertTrue( fd.getName() == "" )
    math1 = fd.getMath()
    self.assertTrue( math1 != None )
    formula = libsbml.formulaToString(math1)
    self.assertTrue( formula != None )
    self.assertTrue((  "lambda(x, x^3)" == formula ))
    self.assertTrue( fd.getMath() != math )
    self.assertEqual( True, fd.isSetMath() )
    self.assertTrue((  "pow3" == fd.getId() ))
    self.assertEqual( True, fd.isSetId() )
    _dummyList = [ math ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ fd ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_FunctionDefinition_createWithNS(self):
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.sbml.org", "testsbml")
    sbmlns = libsbml.SBMLNamespaces(2,1)
    sbmlns.addNamespaces(xmlns)
    object = libsbml.FunctionDefinition(sbmlns)
    self.assertTrue( object.getTypeCode() == libsbml.SBML_FUNCTION_DEFINITION )
    self.assertTrue( object.getMetaId() == "" )
    self.assertTrue( object.getNotes() == None )
    self.assertTrue( object.getAnnotation() == None )
    self.assertTrue( object.getLevel() == 2 )
    self.assertTrue( object.getVersion() == 1 )
    self.assertTrue( object.getNamespaces() != None )
    self.assertTrue( object.getNamespaces().getLength() == 2 )
    _dummyList = [ object ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_FunctionDefinition_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_FunctionDefinition_getArguments(self):
    self.FD.setMath(libsbml.parseFormula("lambda(x, y, x^y)"))
    self.assertTrue( self.FD.getNumArguments() == 2 )
    math = self.FD.getArgument(0)
    self.assertTrue( math != None )
    self.assertEqual( True, math.isName() )
    self.assertTrue((  "x" == math.getName() ))
    self.assertTrue( math.getNumChildren() == 0 )
    math = self.FD.getArgument(1)
    self.assertTrue( math != None )
    self.assertEqual( True, math.isName() )
    self.assertTrue((  "y" == math.getName() ))
    self.assertTrue( math.getNumChildren() == 0 )
    self.assertTrue( self.FD.getArgument(0) == self.FD.getArgument( "x") )
    self.assertTrue( self.FD.getArgument(1) == self.FD.getArgument( "y") )
    pass  

  def test_FunctionDefinition_getBody(self):
    math1 = libsbml.parseFormula("lambda(x, x)")
    self.FD.setMath(math1)
    math = self.FD.getBody()
    self.assertTrue( math != None )
    self.assertEqual( True, math.isName() )
    self.assertTrue((  "x" == math.getName() ))
    self.assertTrue( math.getNumChildren() == 0 )
    _dummyList = [ math1 ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_FunctionDefinition_setId(self):
    id =  "pow3";
    self.FD.setId(id)
    self.assertTrue(( id == self.FD.getId() ))
    self.assertEqual( True, self.FD.isSetId() )
    if (self.FD.getId() == id):
      pass    
    self.FD.setId(self.FD.getId())
    self.assertTrue(( id == self.FD.getId() ))
    self.FD.setId("")
    self.assertEqual( False, self.FD.isSetId() )
    if (self.FD.getId() != None):
      pass    
    pass  

  def test_FunctionDefinition_setMath(self):
    math = libsbml.parseFormula("lambda(x, x^3)")
    self.FD.setMath(math)
    math1 = self.FD.getMath()
    self.assertTrue( math1 != None )
    formula = libsbml.formulaToString(math1)
    self.assertTrue( formula != None )
    self.assertTrue((  "lambda(x, x^3)" == formula ))
    self.assertTrue( self.FD.getMath() != math )
    self.assertEqual( True, self.FD.isSetMath() )
    self.FD.setMath(self.FD.getMath())
    math1 = self.FD.getMath()
    self.assertTrue( math1 != None )
    formula = libsbml.formulaToString(math1)
    self.assertTrue( formula != None )
    self.assertTrue((  "lambda(x, x^3)" == formula ))
    self.assertTrue( self.FD.getMath() != math )
    self.FD.setMath(None)
    self.assertEqual( False, self.FD.isSetMath() )
    if (self.FD.getMath() != None):
      pass    
    pass  

  def test_FunctionDefinition_setName(self):
    name =  "Cube_Me";
    self.FD.setName(name)
    self.assertTrue(( name == self.FD.getName() ))
    self.assertEqual( True, self.FD.isSetName() )
    if (self.FD.getName() == name):
      pass    
    self.FD.setName(self.FD.getName())
    self.assertTrue(( name == self.FD.getName() ))
    self.FD.setName("")
    self.assertEqual( False, self.FD.isSetName() )
    if (self.FD.getName() != None):
      pass    
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestFunctionDefinition))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#
# @file    TestCopyAndClone.py
# @brief   Read SBML unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestCopyAndClone.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestCopyAndClone(unittest.TestCase):


  def test_CompartmentType_assignmentOperator(self):
    o1 = libsbml.CompartmentType(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.CompartmentType(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_CompartmentType_clone(self):
    o1 = libsbml.CompartmentType(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_CompartmentType_copyConstructor(self):
    o1 = libsbml.CompartmentType(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.CompartmentType(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Compartment_assignmentOperator(self):
    o1 = libsbml.Compartment(2,4)
    o1.setId("c")
    o1.setOutside("c2")
    self.assertTrue( o1.getId() ==  "c" )
    self.assertTrue( o1.getOutside() ==  "c2" )
    o2 = libsbml.Compartment(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getOutside() ==  "c2" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Compartment_clone(self):
    o1 = libsbml.Compartment(2,4)
    o1.setId("c")
    o1.setOutside("c2")
    self.assertTrue( o1.getId() ==  "c" )
    self.assertTrue( o1.getOutside() ==  "c2" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getOutside() ==  "c2" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Compartment_copyConstructor(self):
    o1 = libsbml.Compartment(2,4)
    o1.setId("c")
    o1.setOutside("c2")
    self.assertTrue( o1.getId() ==  "c" )
    self.assertTrue( o1.getOutside() ==  "c2" )
    o2 = libsbml.Compartment(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getOutside() ==  "c2" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Constraint_assignmentOperator(self):
    o1 = libsbml.Constraint(2,4)
    o1.setMetaId("c")
    self.assertTrue( o1.getMetaId() ==  "c" )
    text = libsbml.XMLNode.convertStringToXMLNode(" Some text ")
    triple = libsbml.XMLTriple("p", "http://www.w3.org/1999/xhtml", "")
    att = libsbml.XMLAttributes()
    xmlns = libsbml.XMLNamespaces()
    xmlns.add("http://www.w3.org/1999/xhtml")
    p = libsbml.XMLNode(triple,att,xmlns)
    p.addChild(text)
    triple1 = libsbml.XMLTriple("message", "", "")
    att1 = libsbml.XMLAttributes()
    message = libsbml.XMLNode(triple1,att1)
    message.addChild(p)
    math = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(math)
    o1.setMessage(message)
    math = None
    message = None
    self.assertTrue( o1.getMath() != None )
    msg = o1.getMessage()
    self.assertTrue( msg != None )
    o2 = libsbml.Constraint(2,4)
    o2 = o1
    self.assertTrue( o2.getMetaId() ==  "c" )
    self.assertTrue( o2.getMath() != None )
    msg = o2.getMessage()
    self.assertTrue( msg != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Constraint_clone(self):
    o1 = libsbml.Constraint(2,4)
    o1.setMetaId("c")
    self.assertTrue( o1.getMetaId() ==  "c" )
    text = libsbml.XMLNode.convertStringToXMLNode(" Some text ")
    triple = libsbml.XMLTriple("p", "http://www.w3.org/1999/xhtml", "")
    att = libsbml.XMLAttributes()
    xmlns = libsbml.XMLNamespaces()
    xmlns.add("http://www.w3.org/1999/xhtml")
    p = libsbml.XMLNode(triple,att,xmlns)
    p.addChild(text)
    triple1 = libsbml.XMLTriple("message", "", "")
    att1 = libsbml.XMLAttributes()
    message = libsbml.XMLNode(triple1,att1)
    message.addChild(p)
    math = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(math)
    o1.setMessage(message)
    math = None
    message = None
    self.assertTrue( o1.getMath() != None )
    msg = o1.getMessage()
    self.assertTrue( msg != None )
    o2 = o1.clone()
    self.assertTrue( o2.getMetaId() ==  "c" )
    self.assertTrue( o2.getMath() != None )
    msg = o2.getMessage()
    self.assertTrue( msg != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Constraint_copyConstructor(self):
    o1 = libsbml.Constraint(2,4)
    o1.setMetaId("c")
    self.assertTrue( o1.getMetaId() ==  "c" )
    text = libsbml.XMLNode.convertStringToXMLNode(" Some text ")
    triple = libsbml.XMLTriple("p", "http://www.w3.org/1999/xhtml", "")
    att = libsbml.XMLAttributes()
    xmlns = libsbml.XMLNamespaces()
    xmlns.add("http://www.w3.org/1999/xhtml")
    p = libsbml.XMLNode(triple,att,xmlns)
    p.addChild(text)
    triple1 = libsbml.XMLTriple("message", "", "")
    att1 = libsbml.XMLAttributes()
    message = libsbml.XMLNode(triple1,att1)
    message.addChild(p)
    math = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(math)
    o1.setMessage(message)
    math = None
    message = None
    self.assertTrue( o1.getMath() != None )
    msg = o1.getMessage()
    self.assertTrue( msg != None )
    o2 = libsbml.Constraint(o1)
    self.assertTrue( o2.getMetaId() ==  "c" )
    self.assertTrue( o2.getMath() != None )
    msg = o2.getMessage()
    self.assertTrue( msg != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Delay_assignmentOperator(self):
    o1 = libsbml.Delay(2,4)
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.Delay(2,4)
    o2 = o1
    self.assertTrue( o1.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Delay_clone(self):
    o1 = libsbml.Delay(2,4)
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = o1.clone()
    self.assertTrue( o1.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Delay_copyConstructor(self):
    o1 = libsbml.Delay(2,4)
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.Delay(o1)
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_EventAssignment_assignmentOperator(self):
    o1 = libsbml.EventAssignment(2,4)
    o1.setVariable("c2")
    self.assertTrue( o1.getVariable() ==  "c2" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.EventAssignment(2,4)
    o2 = o1
    self.assertTrue( o2.getVariable() ==  "c2" )
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_EventAssignment_clone(self):
    o1 = libsbml.EventAssignment(2,4)
    o1.setVariable("c2")
    self.assertTrue( o1.getVariable() ==  "c2" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = o1.clone()
    self.assertTrue( o2.getVariable() ==  "c2" )
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_EventAssignment_copyConstructor(self):
    o1 = libsbml.EventAssignment(2,4)
    o1.setVariable("c2")
    self.assertTrue( o1.getVariable() ==  "c2" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.EventAssignment(o1)
    self.assertTrue( o2.getVariable() ==  "c2" )
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Event_assignmentOperator(self):
    o1 = libsbml.Event(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.Event(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Event_clone(self):
    o1 = libsbml.Event(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Event_copyConstructor(self):
    o1 = libsbml.Event(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.Event(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_FunctionDefinition_assignmentOperator(self):
    o1 = libsbml.FunctionDefinition(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.FunctionDefinition(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_FunctionDefinition_clone(self):
    o1 = libsbml.FunctionDefinition(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_FunctionDefinition_copyConstructor(self):
    o1 = libsbml.FunctionDefinition(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.FunctionDefinition(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_InitialAssignment_assignmentOperator(self):
    o1 = libsbml.InitialAssignment(2,4)
    o1.setSymbol("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.InitialAssignment(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_InitialAssignment_clone(self):
    o1 = libsbml.InitialAssignment(2,4)
    o1.setSymbol("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_InitialAssignment_copyConstructor(self):
    o1 = libsbml.InitialAssignment(2,4)
    o1.setSymbol("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.InitialAssignment(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_KineticLaw_assignmentOperator(self):
    o1 = libsbml.KineticLaw(2,4)
    p = libsbml.Parameter(2,4)
    p.setId("jake")
    o1.addParameter(p)
    p = None
    self.assertTrue( o1.getNumParameters() == 1 )
    self.assertTrue( o1.getParameter(0).getId() ==  "jake" )
    o2 = libsbml.KineticLaw(2,4)
    o2 = o1
    self.assertTrue( o2.getNumParameters() == 1 )
    self.assertTrue( o2.getParameter(0).getId() ==  "jake" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_KineticLaw_clone(self):
    o1 = libsbml.KineticLaw(2,4)
    p = libsbml.Parameter(2,4)
    p.setId("jake")
    o1.addParameter(p)
    p = None
    self.assertTrue( o1.getNumParameters() == 1 )
    self.assertTrue( o1.getParameter(0).getId() ==  "jake" )
    o2 = o1.clone()
    self.assertTrue( o2.getNumParameters() == 1 )
    self.assertTrue( o2.getParameter(0).getId() ==  "jake" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_KineticLaw_copyConstructor(self):
    o1 = libsbml.KineticLaw(2,4)
    p = libsbml.Parameter(2,4)
    p.setId("jake")
    o1.addParameter(p)
    p = None
    self.assertTrue( o1.getNumParameters() == 1 )
    self.assertTrue( o1.getParameter(0).getId() ==  "jake" )
    o2 = libsbml.KineticLaw(o1)
    self.assertTrue( o2.getNumParameters() == 1 )
    self.assertTrue( o2.getParameter(0).getId() ==  "jake" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_ListOf_assignmentOperator(self):
    o1 = libsbml.ListOf(2,1)
    s = libsbml.Species(2,1)
    s.setId("species_1")
    o1.append(s)
    s = None
    o2 = libsbml.ListOf(2,1)
    o2 = o1
    self.assertTrue( o2.size() == 1 )
    self.assertTrue( o2.get(0).getId() ==  "species_1" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_ListOf_clone(self):
    o1 = libsbml.ListOf(2,1)
    s = libsbml.Species(2,1)
    s.setId("species_1")
    o1.append(s)
    s = None
    o2 = o1.clone()
    self.assertTrue( o2.size() == 1 )
    self.assertTrue( o2.get(0).getId() ==  "species_1" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_ListOf_copyConstructor(self):
    o1 = libsbml.ListOf(2,1)
    s = libsbml.Species(2,1)
    s.setId("species_1")
    o1.append(s)
    s = None
    o2 = libsbml.ListOf(o1)
    self.assertTrue( o2.size() == 1 )
    self.assertTrue( o2.get(0).getId() ==  "species_1" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Parameter_assignmentOperator(self):
    o1 = libsbml.Parameter(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.Parameter(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Parameter_clone(self):
    o1 = libsbml.Parameter(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Parameter_copyConstructor(self):
    o1 = libsbml.Parameter(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.Parameter(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Reaction_assignmentOperator(self):
    o1 = libsbml.Reaction(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    kl = libsbml.KineticLaw(2,4)
    kl.setMath(libsbml.parseFormula("1"))
    o1.setKineticLaw(kl)
    kl = None
    self.assertTrue( o1.isSetKineticLaw() == True )
    self.assertTrue( o1.getKineticLaw() != None )
    o2 = libsbml.Reaction(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.isSetKineticLaw() == True )
    self.assertTrue( o2.getKineticLaw() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Reaction_clone(self):
    o1 = libsbml.Reaction(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    kl = libsbml.KineticLaw(2,4)
    kl.setMath(libsbml.parseFormula("1"))
    o1.setKineticLaw(kl)
    kl = None
    self.assertTrue( o1.isSetKineticLaw() == True )
    self.assertTrue( o1.getKineticLaw() != None )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.isSetKineticLaw() == True )
    self.assertTrue( o2.getKineticLaw() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Reaction_copyConstructor(self):
    o1 = libsbml.Reaction(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    kl = libsbml.KineticLaw(2,4)
    kl.setMath(libsbml.parseFormula("1"))
    o1.setKineticLaw(kl)
    kl = None
    self.assertTrue( o1.isSetKineticLaw() == True )
    self.assertTrue( o1.getKineticLaw() != None )
    o2 = libsbml.Reaction(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.isSetKineticLaw() == True )
    self.assertTrue( o2.getKineticLaw() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Rule_assignmentOperator(self):
    o1 = libsbml.RateRule(2,4)
    o1.setVariable("a")
    self.assertTrue( o1.getVariable() ==  "a" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.isSetMath() == True )
    o2 = libsbml.RateRule(2,4)
    o2 = o1
    self.assertTrue( o2.getVariable() ==  "a" )
    self.assertTrue( o2.isSetMath() == True )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Rule_clone(self):
    o1 = libsbml.RateRule(2,1)
    o1.setVariable("a")
    self.assertTrue( o1.getVariable() ==  "a" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.isSetMath() == True )
    o2 = o1.clone()
    self.assertTrue( o2.getVariable() ==  "a" )
    self.assertTrue( o2.isSetMath() == True )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Rule_copyConstructor(self):
    o1 = libsbml.RateRule(2,1)
    o1.setVariable("a")
    self.assertTrue( o1.getVariable() ==  "a" )
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.isSetMath() == True )
    o2 = libsbml.Rule(o1)
    self.assertTrue( o2.getVariable() ==  "a" )
    self.assertTrue( o2.isSetMath() == True )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_SBMLDocument_assignmentOperator(self):
    o1 = libsbml.SBMLDocument()
    o1.setLevelAndVersion(2,1,False)
    self.assertTrue( o1.getLevel() == 2 )
    self.assertTrue( o1.getVersion() == 1 )
    o2 = libsbml.SBMLDocument()
    o2 = o1
    self.assertTrue( o2.getLevel() == 2 )
    self.assertTrue( o2.getVersion() == 1 )
    o2 = None
    o1 = None
    pass  

  def test_SBMLDocument_clone(self):
    o1 = libsbml.SBMLDocument()
    o1.setLevelAndVersion(1,1,False)
    m = libsbml.Model(1,1)
    m.createCompartment()
    m.createSpecies()
    m.createReaction()
    m.setId("foo")
    o1.setModel(m)
    self.assertTrue( o1.getLevel() == 1 )
    self.assertTrue( o1.getVersion() == 1 )
    self.assertTrue( o1.getModel().getId() ==  "foo" )
    self.assertTrue( o1.getModel().getLevel() == 1 )
    self.assertTrue( o1.getModel().getVersion() == 1 )
    self.assertTrue( o1.getModel().getSBMLDocument() == o1 )
    o2 = o1.clone()
    self.assertTrue( o2.getLevel() == 1 )
    self.assertTrue( o2.getVersion() == 1 )
    self.assertTrue( o2.getModel().getId() ==  "foo" )
    self.assertTrue( o2.getModel().getLevel() == 1 )
    self.assertTrue( o2.getModel().getVersion() == 1 )
    self.assertTrue( o2.getModel().getSBMLDocument() == o2 )
    o2 = None
    o1 = None
    pass  

  def test_SBMLDocument_copyConstructor(self):
    o1 = libsbml.SBMLDocument()
    o1.setLevelAndVersion(2,1,False)
    self.assertTrue( o1.getLevel() == 2 )
    self.assertTrue( o1.getVersion() == 1 )
    o2 = libsbml.SBMLDocument(o1)
    self.assertTrue( o2.getLevel() == 2 )
    self.assertTrue( o2.getVersion() == 1 )
    o2 = None
    o1 = None
    pass  

  def test_SpeciesReference_assignmentOperator(self):
    o1 = libsbml.SpeciesReference(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.SpeciesReference(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_SpeciesReference_clone(self):
    o1 = libsbml.SpeciesReference(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_SpeciesReference_copyConstructor(self):
    o1 = libsbml.SpeciesReference(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.SpeciesReference(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_SpeciesType_assignmentOperator(self):
    o1 = libsbml.SpeciesType(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.SpeciesType(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_SpeciesType_clone(self):
    o1 = libsbml.SpeciesType(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_SpeciesType_copyConstructor(self):
    o1 = libsbml.SpeciesType(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.SpeciesType(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Species_assignmentOperator(self):
    o1 = libsbml.Species(2,4)
    o1.setId("c")
    o1.setSpeciesType("c1")
    self.assertTrue( o1.getId() ==  "c" )
    self.assertTrue( o1.getSpeciesType() ==  "c1" )
    o2 = libsbml.Species(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getSpeciesType() ==  "c1" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Species_clone(self):
    o1 = libsbml.Species(2,4)
    o1.setId("c")
    o1.setSpeciesType("c1")
    self.assertTrue( o1.getId() ==  "c" )
    self.assertTrue( o1.getSpeciesType() ==  "c1" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getSpeciesType() ==  "c1" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Species_copyConstructor(self):
    o1 = libsbml.Species(2,4)
    o1.setId("c")
    o1.setSpeciesType("c1")
    self.assertTrue( o1.getId() ==  "c" )
    self.assertTrue( o1.getSpeciesType() ==  "c1" )
    o2 = libsbml.Species(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getSpeciesType() ==  "c1" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Trigger_assignmentOperator(self):
    o1 = libsbml.Trigger(2,4)
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.Trigger(2,4)
    o2 = o1
    self.assertTrue( o1.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Trigger_clone(self):
    o1 = libsbml.Trigger(2,4)
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = o1.clone()
    self.assertTrue( o1.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Trigger_copyConstructor(self):
    o1 = libsbml.Trigger(2,4)
    node = libsbml.ASTNode(libsbml.AST_CONSTANT_PI)
    o1.setMath(node)
    node = None
    self.assertTrue( o1.getMath() != None )
    o2 = libsbml.Trigger(o1)
    self.assertTrue( o2.getMath() != None )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_UnitDefinition_assignmentOperator(self):
    o1 = libsbml.UnitDefinition(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.UnitDefinition(2,4)
    o2 = o1
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_UnitDefinition_clone(self):
    o1 = libsbml.UnitDefinition(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = o1.clone()
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_UnitDefinition_copyConstructor(self):
    o1 = libsbml.UnitDefinition(2,4)
    o1.setId("c")
    self.assertTrue( o1.getId() ==  "c" )
    o2 = libsbml.UnitDefinition(o1)
    self.assertTrue( o2.getId() ==  "c" )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Unit_assignmentOperator(self):
    o1 = libsbml.Unit(2,4)
    o1.setKind(libsbml.UNIT_KIND_MOLE)
    self.assertTrue( o1.getKind() == libsbml.UNIT_KIND_MOLE )
    o2 = libsbml.Unit(2,4)
    o2 = o1
    self.assertTrue( o2.getKind() == libsbml.UNIT_KIND_MOLE )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Unit_clone(self):
    o1 = libsbml.Unit(2,4)
    o1.setKind(libsbml.UNIT_KIND_MOLE)
    self.assertTrue( o1.getKind() == libsbml.UNIT_KIND_MOLE )
    o2 = o1.clone()
    self.assertTrue( o2.getKind() == libsbml.UNIT_KIND_MOLE )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

  def test_Unit_copyConstructor(self):
    o1 = libsbml.Unit(2,4)
    o1.setKind(libsbml.UNIT_KIND_MOLE)
    self.assertTrue( o1.getKind() == libsbml.UNIT_KIND_MOLE )
    o2 = libsbml.Unit(o1)
    self.assertTrue( o2.getKind() == libsbml.UNIT_KIND_MOLE )
    self.assertTrue( o2.getParentSBMLObject() == o1.getParentSBMLObject() )
    o2 = None
    o1 = None
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestCopyAndClone))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)

